==> react-common-bootstrap-2.0.37.tgz: package/form/CustomFormFieldInputList.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useState } from 'react';
import CreatableSelect from 'react-select/creatable';
import { useFormContext } from './CustomForm';
import { reactSelectStyle } from './react-select-style';
const components = {
  DropdownIndicator: null
};
const CustomFormFieldInputList = ({
  label = '',
  feedback = inputValue => `La valeur ${inputValue} est invalide`,
  value,
  onChange,
  validator = inputValue => inputValue != '',
  disabled = false,
  isValid = true,
  placeholder = '',
  hint = '',
  ...args
}) => {
  const [inputValue, setInputValue] = useState('');
  const handleKeyDown = event => {
    if (!inputValue) return;
    switch (event.key) {
      case 'Enter':
      case 'Tab':
        event.preventDefault();
        addValue();
    }
  };
  const addValue = () => {
    if (validator(inputValue)) {
      onChange([...value, inputValue]);
      setInputValue('');
    }
  };
  const {
    displayError
  } = useFormContext();
  return /*#__PURE__*/React.createElement("div", {
    className: "custom-form-field flex1"
  }, /*#__PURE__*/React.createElement("label", null, label), /*#__PURE__*/React.createElement(CreatableSelect, _extends({
    formatCreateLabel: () => !validator(inputValue) && feedback != null ? feedback(inputValue) : `Ajouter "${inputValue}"`,
    components: components,
    inputValue: inputValue,
    isMulti: true,
    onChange: addValue,
    onInputChange: newValue => setInputValue(newValue),
    onKeyDown: handleKeyDown,
    value: value.map(v => ({
      value: v,
      label: v
    })),
    isDisabled: disabled,
    noOptionsMessage: () => null,
    placeholder: placeholder
  }, reactSelectStyle(displayError, isValid), args)), hint != '' && /*#__PURE__*/React.createElement("small", null, hint));
};
export default CustomFormFieldInputList;

==> react-common-bootstrap-2.0.38.tgz: package/form/CustomFormFieldInputList.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useState } from 'react';
import CreatableSelect from 'react-select/creatable';
import { useFormContext } from './CustomForm';
import { reactSelectStyle } from './react-select-style';
const components = {
  DropdownIndicator: null
};
const CustomFormFieldInputList = ({
  label = '',
  feedback = inputValue => `La valeur ${inputValue} est invalide`,
  value,
  onChange,
  validator = inputValue => inputValue != '',
  disabled = false,
  isValid = true,
  placeholder = '',
  hint = '',
  ...args
}) => {
  const [inputValue, setInputValue] = useState('');
  const handleKeyDown = event => {
    if (!inputValue) return;
    switch (event.key) {
      case 'Enter':
      case 'Tab':
        event.preventDefault();
        addValue();
    }
  };
  const addValue = (newValues, action) => {
    if (validator(inputValue)) {
      onChange([...value, inputValue]);
      setInputValue('');
    }
    if (action != null && action.action === 'remove-value') {
      onChange([...newValues.map(({
        value
      }) => value)]);
    }
  };
  const {
    displayError
  } = useFormContext();
  return /*#__PURE__*/React.createElement("div", {
    className: "custom-form-field flex1"
  }, /*#__PURE__*/React.createElement("label", null, label), /*#__PURE__*/React.createElement(CreatableSelect, _extends({
    formatCreateLabel: () => !validator(inputValue) && feedback != null ? feedback(inputValue) : `Ajouter "${inputValue}"`,
    components: components,
    inputValue: inputValue,
    isMulti: true,
    onChange: addValue,
    onInputChange: newValue => setInputValue(newValue),
    onKeyDown: handleKeyDown,
    value: value.map(v => ({
      value: v,
      label: v
    })),
    isDisabled: disabled,
    noOptionsMessage: () => null,
    placeholder: placeholder
  }, reactSelectStyle(displayError, isValid), args)), hint != '' && /*#__PURE__*/React.createElement("small", null, hint));
};
export default CustomFormFieldInputList;
